@@ -166,7 +166,10 @@ void DirectionalCompressorAudioProcessor::processBlock (AudioSampleBuffer& buffe
     const int totalNumInputChannels  = getTotalNumInputChannels();
     const int totalNumOutputChannels = getTotalNumOutputChannels();
     const int bufferSize = buffer.getNumSamples();
-    //const int ambisonicOrder = input.getOrder();
+
+    const int numCh = jmin(input.getNumberOfChannels(), buffer.getNumChannels());
+    if (numCh == 0)
+           return;
 
     // Compressor 1 settings
     if (*c1Ratio > 15.9f)
@@ -192,22 +195,18 @@ void DirectionalCompressorAudioProcessor::processBlock (AudioSampleBuffer& buffe
     compressor2.setThreshold(*c2Threshold);
     compressor2.setMakeUpGain(*c2Makeup);
 
-
     drivingPointers[0] = maskBuffer.getReadPointer(0);
     drivingPointers[1] = buffer.getReadPointer(0);
     drivingPointers[2] = omniW.getReadPointer(0);
 
-
-    const int numCh = jmin(input.getNumberOfChannels(), buffer.getNumChannels());
-
     // preGain - can be tweaked by adding gain to compressor gains
-    float preGainLinear = Decibels::decibelsToGain(*preGain);
+    float preGainLinear = Decibels::decibelsToGain (preGain->load());
 
     if (*useSN3D >= 0.5f)
         for (int i = 0; i < numCh; ++i)
             buffer.applyGain(i, 0, bufferSize, sn3d2n3d[i] * preGainLinear);
     else
-        buffer.applyGain(Decibels::decibelsToGain(*preGain));
+        buffer.applyGain (Decibels::decibelsToGain (preGain->load()));
 
 
     // --------- make copys of buffer
