@@ -31,11 +31,11 @@
 using namespace juce::dsp;
 
 #if JUCE_USE_SIMD
-# define IIRfloat juce::dsp::SIMDRegister<float>
-# define IIRfloat_elements() IIRfloat::SIMDNumElements
+    using IIRfloat = juce::dsp::SIMDRegister<float>;
+    static constexpr int IIRfloat_elements = juce::dsp::SIMDRegister<float>::size();
 #else /* !JUCE_USE_SIMD */
-# define IIRfloat float
-# define IIRfloat_elements() 1
+    using IIRfloat = float;
+    static constexpr int IIRfloat_elements = 1;
 #endif /* JUCE_USE_SIMD */
 
 #define ProcessorClass MultiEQAudioProcessor
@@ -127,12 +127,12 @@ private:
 
 
     // list of used audio parameters
-    float *inputChannelsSetting;
-    float* filterEnabled[numFilterBands];
-    float* filterType[numFilterBands];
-    float* filterFrequency[numFilterBands];
-    float* filterQ[numFilterBands];
-    float* filterGain[numFilterBands];
+    std::atomic<float>* inputChannelsSetting;
+    std::atomic<float>* filterEnabled[numFilterBands];
+    std::atomic<float>* filterType[numFilterBands];
+    std::atomic<float>* filterFrequency[numFilterBands];
+    std::atomic<float>* filterQ[numFilterBands];
+    std::atomic<float>* filterGain[numFilterBands];
 
     // filters for processing
     OwnedArray<IIR::Filter<IIRfloat>> filterArrays[numFilterBands];
