@@ -25,7 +25,7 @@
 
 //==============================================================================
 ProbeDecoderAudioProcessorEditor::ProbeDecoderAudioProcessorEditor (ProbeDecoderAudioProcessor& p, AudioProcessorValueTreeState& vts)
-: AudioProcessorEditor (&p), footer (p.getOSCReceiver()), processor (p), valueTreeState(vts),
+: AudioProcessorEditor (&p), footer (p.getOSCParameterInterface()), processor (p), valueTreeState(vts),
 probe(*valueTreeState.getParameter("azimuth"), valueTreeState.getParameterRange("azimuth"),
       *valueTreeState.getParameter("elevation"), valueTreeState.getParameterRange("elevation"))
 {
@@ -51,12 +51,13 @@ probe(*valueTreeState.getParameter("azimuth"), valueTreeState.getParameterRange(
 
     addAndMakeVisible(&footer);
 
+    toolTipWin.setLookAndFeel (&globalLaF);
     toolTipWin.setMillisecondsBeforeTipAppears(500);
     toolTipWin.setOpaque (false);
 
 
-    cbNormalizationAtachement = new ComboBoxAttachment(valueTreeState,"useSN3D", *title.getInputWidgetPtr()->getNormCbPointer());
-    cbOrderAtachement = new ComboBoxAttachment(valueTreeState,"orderSetting", *title.getInputWidgetPtr()->getOrderCbPointer());
+    cbNormalizationAtachement.reset (new ComboBoxAttachment (valueTreeState,"useSN3D", *title.getInputWidgetPtr()->getNormCbPointer()));
+    cbOrderAtachement.reset (new ComboBoxAttachment (valueTreeState,"orderSetting", *title.getInputWidgetPtr()->getOrderCbPointer()));
 
 
     // ======================== YAW PITCH ROLL GROUP
@@ -68,7 +69,7 @@ probe(*valueTreeState.getParameter("azimuth"), valueTreeState.getParameterRange(
     ypGroup.setVisible(true);
 
     addAndMakeVisible(&slAzimuth);
-    slAzimuthAttachment = new SliderAttachment(valueTreeState,"azimuth", slAzimuth);
+    slAzimuthAttachment.reset (new SliderAttachment (valueTreeState,"azimuth", slAzimuth));
     slAzimuth.setSliderStyle (Slider::RotaryHorizontalVerticalDrag);
     slAzimuth.setTextBoxStyle (Slider::TextBoxBelow, false, 50, 15);
     slAzimuth.setReverse(true);
@@ -78,7 +79,7 @@ probe(*valueTreeState.getParameter("azimuth"), valueTreeState.getParameterRange(
     slAzimuth.setTextValueSuffix(CharPointer_UTF8 (R"(°)"));
 
     addAndMakeVisible(&slElevation);
-    slElevationAttachment = new SliderAttachment(valueTreeState,"elevation", slElevation);
+    slElevationAttachment.reset (new SliderAttachment (valueTreeState,"elevation", slElevation));
     slElevation.setSliderStyle (Slider::RotaryHorizontalVerticalDrag);
     slElevation.setTextBoxStyle (Slider::TextBoxBelow, false, 50, 15);
     slElevation.setColour (Slider::rotarySliderOutlineColourId, globalLaF.ClWidgetColours[1]);
@@ -93,7 +94,7 @@ probe(*valueTreeState.getParameter("azimuth"), valueTreeState.getParameterRange(
     addAndMakeVisible(&lbElevation);
     lbElevation.setText("Elevation");
 
-    startTimer(10);
+    startTimer (20);
 }
 
 
@@ -111,9 +112,7 @@ void ProbeDecoderAudioProcessorEditor::paint (Graphics& g)
 void ProbeDecoderAudioProcessorEditor::timerCallback()
 {
     // === update titleBar widgets according to available input/output channel counts
-    int maxInSize, maxOutSize;
-    processor.getMaxSize(maxInSize, maxOutSize);
-    title.setMaxSize(maxInSize, maxOutSize);
+    title.setMaxSize (processor.getMaxSize());
     // ==========================================
 
     if (processor.updatedPositionData.get())
