@@ -116,8 +116,8 @@ createParameterLayout())
         FloatVectorOperations::clear((float *) &SHsampleOld[i], 64);
     }
 
-    lowShelfCoefficients = IIR::Coefficients<float>::makeLowShelf(48000, *lowShelfFreq, 0.707f, Decibels::decibelsToGain(*lowShelfGain));
-    highShelfCoefficients = IIR::Coefficients<float>::makeHighShelf(48000, *highShelfFreq, 0.707f, Decibels::decibelsToGain(*highShelfGain));
+    lowShelfCoefficients = IIR::Coefficients<float>::makeLowShelf(48000, *lowShelfFreq, 0.707f, Decibels::decibelsToGain (lowShelfGain->load()));
+    highShelfCoefficients = IIR::Coefficients<float>::makeHighShelf(48000, *highShelfFreq, 0.707f, Decibels::decibelsToGain (highShelfGain->load()));
 
 
     lowShelfArray.clear();
@@ -264,7 +264,7 @@ void RoomEncoderAudioProcessor::prepareToPlay (double sampleRate, int samplesPer
         clear (*interleavedData.getLast());
     }
 
-    zero = AudioBlock<float> (zeroData, IIRfloat_elements(), samplesPerBlock);
+    zero = AudioBlock<float> (zeroData, IIRfloat_elements, samplesPerBlock);
     zero.clear();
 
     updateFv = true;
@@ -277,14 +277,14 @@ void RoomEncoderAudioProcessor::prepareToPlay (double sampleRate, int samplesPer
     const float rYHalfBound = rY / 2 - 0.1f;
     const float rZHalfBound = rZ / 2 - 0.1f;
 
-    sourcePos = Vector3D<float> (jlimit (-rXHalfBound, rXHalfBound, *sourceX),
-                                 jlimit (-rYHalfBound, rYHalfBound, *sourceY),
-                                 jlimit (-rZHalfBound, rZHalfBound, *sourceZ));
+    sourcePos = Vector3D<float> (jlimit (-rXHalfBound, rXHalfBound, sourceX->load()),
+                                 jlimit (-rYHalfBound, rYHalfBound, sourceY->load()),
+                                 jlimit (-rZHalfBound, rZHalfBound, sourceZ->load()));
 
 
-    listenerPos = Vector3D<float> (jlimit (-rXHalfBound, rXHalfBound, *listenerX),
-                                   jlimit (-rYHalfBound, rYHalfBound, *listenerY),
-                                   jlimit (-rZHalfBound, rZHalfBound, *listenerZ));
+    listenerPos = Vector3D<float> (jlimit (-rXHalfBound, rXHalfBound, listenerX->load()),
+                                   jlimit (-rYHalfBound, rYHalfBound, listenerY->load()),
+                                   jlimit (-rZHalfBound, rZHalfBound, listenerZ->load()));
 
     calculateImageSourcePositions (rX, rY, rZ);
 
@@ -363,11 +363,11 @@ void RoomEncoderAudioProcessor::parameterChanged (const String &parameterID, flo
 
 void RoomEncoderAudioProcessor::updateFilterCoefficients (double sampleRate)
 {
-    const auto lowFreq = jmin (static_cast<float> (0.5 * sampleRate), *lowShelfFreq);
-    *lowShelfCoefficients = *IIR::Coefficients<float>::makeLowShelf (sampleRate, lowFreq, 0.707f, Decibels::decibelsToGain (*lowShelfGain));
+    const auto lowFreq = jmin (static_cast<float> (0.5 * sampleRate), lowShelfFreq->load());
+    *lowShelfCoefficients = *IIR::Coefficients<float>::makeLowShelf (sampleRate, lowFreq, 0.707f, Decibels::decibelsToGain (lowShelfGain->load()));
 
-    const auto highFreq = jmin (static_cast<float> (0.5 * sampleRate), *highShelfFreq);
-    *highShelfCoefficients = *IIR::Coefficients<float>::makeHighShelf (sampleRate, highFreq, 0.707f, Decibels::decibelsToGain (*highShelfGain));
+    const auto highFreq = jmin (static_cast<float> (0.5 * sampleRate), highShelfFreq->load());
+    *highShelfCoefficients = *IIR::Coefficients<float>::makeHighShelf (sampleRate, highFreq, 0.707f, Decibels::decibelsToGain (highShelfGain->load()));
 
     userChangedFilterSettings = false;
     updateFv = true;
@@ -416,23 +416,27 @@ void RoomEncoderAudioProcessor::processBlock (AudioSampleBuffer& buffer, MidiBuf
     float* pBufferWrite = buffer.getWritePointer(0);
     const float* pBufferRead = buffer.getReadPointer(0);
 
-    const int nSIMDFilters = 1 + (maxNChIn-1)/IIRfloat_elements();
+    const int nSIMDFilters = 1 + (maxNChIn-1)/IIRfloat_elements;
 
     const auto delayBufferWritePtrArray = delayBuffer.getArrayOfWritePointers();
 
+
+    if (maxNChIn < 1)
+        return;
+    
     // update iir filter coefficients
     if (userChangedFilterSettings) updateFilterCoefficients(sampleRate);
 
 
     //interleave input data
-    int partial = maxNChIn%IIRfloat_elements();
+    int partial = maxNChIn%IIRfloat_elements;
     if (partial == 0)
     {
         for (int i = 0; i<nSIMDFilters; ++i)
         {
-            AudioDataConverters::interleaveSamples(buffer.getArrayOfReadPointers() + i*IIRfloat_elements(),
+            AudioDataConverters::interleaveSamples(buffer.getArrayOfReadPointers() + i*IIRfloat_elements,
                                                    reinterpret_cast<float*> (interleavedData[i]->getChannelPointer (0)), L,
-                                                   static_cast<int> (IIRfloat_elements()));
+                                                   static_cast<int> (IIRfloat_elements));
         }
     }
     else
@@ -440,32 +444,32 @@ void RoomEncoderAudioProcessor::processBlock (AudioSampleBuffer& buffer, MidiBuf
         int i;
         for (i = 0; i<nSIMDFilters-1; ++i)
         {
-            AudioDataConverters::interleaveSamples(buffer.getArrayOfReadPointers() + i*IIRfloat_elements(),
+            AudioDataConverters::interleaveSamples(buffer.getArrayOfReadPointers() + i*IIRfloat_elements,
                                                    reinterpret_cast<float*> (interleavedData[i]->getChannelPointer (0)), L,
-                                                   static_cast<int> (IIRfloat_elements()));
+                                                   static_cast<int> (IIRfloat_elements));
         }
 
-        const float* addr[IIRfloat_elements()];
+        const float* addr[IIRfloat_elements];
         size_t ch;
         for (ch = 0; ch < partial; ++ch)
         {
-            addr[ch] = buffer.getReadPointer(i * static_cast<int> (IIRfloat_elements() + ch));
+            addr[ch] = buffer.getReadPointer(i * static_cast<int> (IIRfloat_elements + ch));
         }
-        for (; ch < IIRfloat_elements(); ++ch)
+        for (; ch < IIRfloat_elements; ++ch)
         {
             addr[ch] = zero.getChannelPointer(ch);
         }
         AudioDataConverters::interleaveSamples(addr,
                                                reinterpret_cast<float*> (interleavedData[i]->getChannelPointer (0)), L,
-                                               static_cast<int> (IIRfloat_elements()));
+                                               static_cast<int> (IIRfloat_elements));
     }
 
-    int currNumRefl = roundToInt(*numRefl);
+    int currNumRefl = roundToInt (numRefl->load());
     int workingNumRefl = (currNumRefl < _numRefl) ? _numRefl : currNumRefl;
 
 
     // calculating reflection coefficients (only if parameter changed)
-    float reflCoeffGain = Decibels::decibelsToGain(*reflCoeff);
+    float reflCoeffGain = Decibels::decibelsToGain (reflCoeff->load());
     if (powReflCoeff[1] != reflCoeffGain)
     {
         powReflCoeff[0] = 1;
@@ -538,10 +542,10 @@ void RoomEncoderAudioProcessor::processBlock (AudioSampleBuffer& buffer, MidiBuf
         {
             for (int i = 0; i<nSIMDFilters; ++i)
             {
-                const SIMDRegister<float>* chPtr[1];
+                const IIRfloat* chPtr[1];
                 chPtr[0] = interleavedData[i]->getChannelPointer (0);
-                AudioBlock<SIMDRegister<float>> ab (const_cast<SIMDRegister<float>**> (chPtr), 1, L);
-                ProcessContextReplacing<SIMDRegister<float>> context (ab);
+                AudioBlock<IIRfloat> ab (const_cast<IIRfloat**> (chPtr), 1, L);
+                ProcessContextReplacing<IIRfloat> context (ab);
 
                 lowShelfArray[idx]->getUnchecked (i)->process (context);
                 highShelfArray[idx]->getUnchecked (i)->process (context);
@@ -553,15 +557,15 @@ void RoomEncoderAudioProcessor::processBlock (AudioSampleBuffer& buffer, MidiBuf
          * the following section is broken, as it hardcodes asumptions about how
          * many floats can be stored in IIRfloat
          */
-        IIRfloat SHsample[16]; //TODO: can be smaller: (N+1)^2/IIRfloat_elements()
+        IIRfloat SHsample[16]; //TODO: can be smaller: (N+1)^2/IIRfloat_elements
         IIRfloat SHsampleStep[16];
 #if JUCE_USE_SIMD
         FloatVectorOperations::clear((float *) &SHsample->value,
-                                     IIRfloat_elements() * sizeof(SHsample) / sizeof(*SHsample));
+                                     IIRfloat_elements * sizeof(SHsample) / sizeof(*SHsample));
         SHEval(directivityOrder, smx[q], smy[q], smz[q],(float *) &SHsample->value, false); // deoding -> false
 #else  /* !JUCE_USE_SIMD */
         FloatVectorOperations::clear((float *) SHsample,
-                                     IIRfloat_elements() * sizeof(SHsample) / sizeof(*SHsample));
+                                     IIRfloat_elements * sizeof(SHsample) / sizeof(*SHsample));
         SHEval(directivityOrder, smx[q], smy[q], smz[q],(float *) SHsample, false); // deoding -> false
 #endif /* JUCE_USE_SIMD */
 
@@ -1135,7 +1139,7 @@ std::vector<std::unique_ptr<RangedAudioParameter>> RoomEncoderAudioProcessor::cr
 
 inline void RoomEncoderAudioProcessor::clear (AudioBlock<IIRfloat>& ab)
 {
-    const int N = static_cast<int> (ab.getNumSamples()) * IIRfloat_elements();
+    const int N = static_cast<int> (ab.getNumSamples()) * IIRfloat_elements;
     const int nCh = static_cast<int> (ab.getNumChannels());
 
     for (int ch = 0; ch < nCh; ++ch)
