@@ -26,7 +26,7 @@
 
 //==============================================================================
 PluginTemplateAudioProcessorEditor::PluginTemplateAudioProcessorEditor (PluginTemplateAudioProcessor& p, AudioProcessorValueTreeState& vts)
-    : AudioProcessorEditor (&p), processor (p), valueTreeState (vts), footer (p.getOSCReceiver())
+    : AudioProcessorEditor (&p), audioProcessor (p), valueTreeState (vts), footer (p.getOSCParameterInterface())
 {
     // ============== BEGIN: essentials ======================
     // set GUI size and lookAndFeel
@@ -43,14 +43,14 @@ PluginTemplateAudioProcessorEditor::PluginTemplateAudioProcessorEditor (PluginTe
 
 
     // create the connection between title component's comboBoxes and parameters
-    cbInputChannelsSettingAttachment = new ComboBoxAttachment (valueTreeState, "inputChannelsSetting", *title.getInputWidgetPtr()->getChannelsCbPointer());
-    cbNormalizationSettingAttachment = new ComboBoxAttachment (valueTreeState, "useSN3D", *title.getOutputWidgetPtr()->getNormCbPointer());
-    cbOrderSettingAttachment = new ComboBoxAttachment (valueTreeState, "outputOrderSetting", *title.getOutputWidgetPtr()->getOrderCbPointer());
+    cbInputChannelsSettingAttachment.reset (new ComboBoxAttachment (valueTreeState, "inputChannelsSetting", *title.getInputWidgetPtr()->getChannelsCbPointer()));
+    cbNormalizationSettingAttachment.reset (new ComboBoxAttachment (valueTreeState, "useSN3D", *title.getOutputWidgetPtr()->getNormCbPointer()));
+    cbOrderSettingAttachment.reset (new ComboBoxAttachment (valueTreeState, "outputOrderSetting", *title.getOutputWidgetPtr()->getOrderCbPointer()));
 
     addAndMakeVisible (slParam1);
-    slParam1Attachment = new SliderAttachment (valueTreeState, "param1", slParam1);
+    slParam1Attachment.reset (new SliderAttachment (valueTreeState, "param1", slParam1));
     addAndMakeVisible (slParam2);
-    slParam2Attachment = new SliderAttachment (valueTreeState, "param2", slParam2);
+    slParam2Attachment.reset (new SliderAttachment (valueTreeState, "param2", slParam2));
 
 
     // start timer after everything is set up properly
@@ -101,9 +101,7 @@ void PluginTemplateAudioProcessorEditor::resized()
 void PluginTemplateAudioProcessorEditor::timerCallback()
 {
     // === update titleBar widgets according to available input/output channel counts
-    int maxInSize, maxOutSize;
-    processor.getMaxSize (maxInSize, maxOutSize);
-    title.setMaxSize (maxInSize, maxOutSize);
+    title.setMaxSize (audioProcessor.getMaxSize());
     // ==========================================
 
     // insert stuff you want to do be done at every timer callback
