@@ -2,11 +2,13 @@
 cd ${0%/*}
 rm -rf */Builds
 rm -rf */JuceLibraryCode
+rm -Rf _compiledPlugins/macOS/IEM
+rm -Rf _compiledPlugins/macOS/Standalone
 mkdir -p _compiledPlugins/macOS/IEM
 mkdir -p _compiledPlugins/macOS/Standalone
 for d in */*.jucer; do
-  open -W -n ${PWD}/${d} --args --resave ${PWD}/${d}
-  d=${d%/*}
+  open -W -n "${PWD}/${d}" --args --resave "${PWD}/${d}"
+  d="${d%/*}"
   echo "Compiling $d for macOS..."
     if [ -d "${d}/Builds/MacOSX" ]; then
         pushd "${d}/Builds/MacOSX"
